<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>Rexistro dos cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>GUI para aplicar diversas melloras útiles</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>launches brightness-systray</source>
        <translation>lanza brightness-systray</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>abre co separador de visualización aberto. Só válido cun escritorio Xfce en execución</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>Abre a lapela do tema directamente. Válido nos escritorios Xfce e Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Display additional debug output in console</source>
        <translation>Mostra a saída de depuración adicional na consola</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation>Abre directamente outra guía. Válido en todos os escritorios</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Lapela principal</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Brillo controlado polo software (xrandr)</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>Rótulo de texto</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Retroiluminación da pantalla</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX-axustes rápidos</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Amosar</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;Saír</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="60"/>
        <location filename="../defaultlook.cpp" line="108"/>
        <location filename="../defaultlook.cpp" line="672"/>
        <location filename="../defaultlook.cpp" line="691"/>
        <location filename="../defaultlook.cpp" line="700"/>
        <location filename="../defaultlook.cpp" line="747"/>
        <location filename="../defaultlook.cpp" line="755"/>
        <location filename="../defaultlook.cpp" line="782"/>
        <location filename="../defaultlook.cpp" line="785"/>
        <source>MX Tweak</source>
        <translation>MX axustes rápidos</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="41"/>
        <source>Xfce Settings</source>
        <translation>Configuración do Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="107"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="118"/>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="135"/>
        <source>Quit application</source>
        <translation>Saír do aplicativo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="138"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="145"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="165"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personalizar o panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="175"/>
        <location filename="../defaultlook.ui" line="259"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="195"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configurar o comportamento das lapelas e dos atallos&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="209"/>
        <source>Window Manager</source>
        <translation>Xestor de lapelas</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="229"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personalizar o aspecto do escritorio&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="270"/>
        <source>Display panel horizontally</source>
        <extracomment>panel will be shown in a horizontal configuration</extracomment>
        <translation>Exhibir o panel en horizontal</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="280"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="287"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the docklike plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="294"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Afecta a todos os paneis&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="314"/>
        <location filename="../defaultlook.ui" line="1798"/>
        <source>Bottom</source>
        <translation>Abaixo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="319"/>
        <location filename="../defaultlook.ui" line="1808"/>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="327"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="334"/>
        <source>Display panel vertically</source>
        <extracomment>panel will be shown in a vertical configuration</extracomment>
        <translation>Exhibir o panel na vertical</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="349"/>
        <location filename="../defaultlook.ui" line="1787"/>
        <source>Affects 1st panel</source>
        <extracomment>acts on the first poanel found in Xfce panel xml fle</extracomment>
        <translation>Afecta ao panel 1</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="356"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Scales&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Escalas de complementos do panel&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="376"/>
        <source>Backup current panel configuration</source>
        <extracomment>backup existing panel configuration</extracomment>
        <translation>Gardar a configuración actual do panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="386"/>
        <location filename="../defaultlook.ui" line="446"/>
        <source>Options</source>
        <translation>Opcións</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="406"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>Xestor de energia</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="413"/>
        <source>Restore backup panel configuration</source>
        <extracomment>restore a panel backup</extracomment>
        <translation>Restaurar a configuración do panel gardado</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="436"/>
        <source>Set Scales</source>
        <extracomment>set a scale factor</extracomment>
        <translation>Establecer escalas</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="466"/>
        <location filename="../defaultlook.ui" line="1803"/>
        <source>Left</source>
        <translation>Á esquerda</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="471"/>
        <location filename="../defaultlook.ui" line="1813"/>
        <source>Right</source>
        <translation>Á dereita</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="479"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the window button plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Botóns da lapela&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="500"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is the modern dock plugin for the panel.  Window Buttons is the classic tasklist without dock features.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike é o complemento moderno do panel. Window Buttons é a lista de tarefas clásica sen características de dock.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="523"/>
        <location filename="../defaultlook.ui" line="722"/>
        <location filename="../defaultlook.ui" line="896"/>
        <location filename="../defaultlook.ui" line="1064"/>
        <location filename="../defaultlook.ui" line="1071"/>
        <location filename="../defaultlook.ui" line="1078"/>
        <location filename="../defaultlook.ui" line="1145"/>
        <location filename="../defaultlook.ui" line="1290"/>
        <location filename="../defaultlook.ui" line="1839"/>
        <location filename="../defaultlook.ui" line="1898"/>
        <location filename="../defaultlook.ui" line="2045"/>
        <source>Apply</source>
        <extracomment>apply changes</extracomment>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="543"/>
        <source>Restore default panel</source>
        <extracomment>affects any panel that is curently configured</extracomment>
        <translation>Restaurar o panel predeterminado</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="553"/>
        <source>Set Tasklist plugin to:</source>
        <extracomment>change the tasklist plugin</extracomment>
        <translation>Configura o plugin Tasklist para:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="567"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="575"/>
        <source>Preview</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="582"/>
        <source>Remove User Theme Set</source>
        <translation>Eliminar tema do usuario</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="593"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>Gardar as configuracións actuais como tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="604"/>
        <source>default</source>
        <extracomment>default pointer size determined by X server</extracomment>
        <translation>predeterminado</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="617"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Temas&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="624"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>icon theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Iconas&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="631"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Cursors&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>cursor theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Cursors&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="638"/>
        <source>Size</source>
        <extracomment>size of the mouse pointer or cursor</extracomment>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="651"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Xestor de xanelas&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="666"/>
        <source>Theme Options</source>
        <translation>Opcións de tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="682"/>
        <source>Undo</source>
        <translation>Desfacer</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="689"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme an application will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Aplicativo&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="745"/>
        <location filename="../defaultlook.ui" line="756"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="763"/>
        <source>Transparency and shadow options</source>
        <translation>Opcións de transparencia e sombreado</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="783"/>
        <source>None</source>
        <translation>Ningún</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="788"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Compositoir do Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="793"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="802"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="807"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="812"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="817"/>
        <location filename="../defaultlook.ui" line="1403"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>apagado</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="838"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Cambiar o modo VBlank pode axudar a aliviar algúns problemas de distorsión na pantalla. Consultar a axuda para máis información.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="841"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="848"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Executar a ferramenta de configuración compton-conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="851"/>
        <source>Compton settings</source>
        <translation>Configuración do Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="862"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Editar o ficheiro compton.conf directamente no editor de texto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="865"/>
        <source>Edit compton.conf</source>
        <translation>Editar compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="876"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configuración do compositor do Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="879"/>
        <source>Xfwm Settings</source>
        <translation>Configuración do Xfwm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="919"/>
        <source>Display</source>
        <translation>Display</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="930"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>Retroiluminación da pantalla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="937"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Axustes da pantalla&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="964"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>Escoller pantalla para axustes do xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="974"/>
        <source>Resolution</source>
        <translation>Resolución</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="981"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Gardar é por pantalla&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="984"/>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="991"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>Brillo controlado polo software (xrandr)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="998"/>
        <location filename="../defaultlook.ui" line="1095"/>
        <source>TextLabel</source>
        <translation>Rótulo de texto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1005"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>Escala GTK</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1025"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>Escala xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1121"/>
        <source>Config Options</source>
        <translation>Opcións da configuración</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1132"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Desactivar o acurtamento dos nomes dos ficheiros</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1156"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   nota: para o sistema poder hibernar, a partición swap ten que ser &gt;= RAM instalada</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1176"/>
        <source>Enable single-click on desktop</source>
        <translation>Acivar premer único</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1183"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Activar &apos;Hibernar&apos; no menú Saír</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1190"/>
        <location filename="../defaultlook.ui" line="1324"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Restablecer as accións predeterminadas do botón directo do rato en Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1197"/>
        <location filename="../defaultlook.ui" line="1375"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Activar cun premer no xestor de ficheiros Thumar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1204"/>
        <location filename="../defaultlook.ui" line="1636"/>
        <source>Thunar windows always open in split view</source>
        <translation>As xanelas do Thunar sempre abren en vista dividida</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1211"/>
        <location filename="../defaultlook.ui" line="1568"/>
        <source>Thunar split view opens horizontal</source>
        <translation>A vista dividida do Thunar abre en horizontal</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1218"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Mostrar porcentaxes nas notificacións cando estean dispoñibles</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1225"/>
        <source>Enable Desktop Zoom </source>
        <translation>Activa a ampliación do escritorio</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1232"/>
        <location filename="../defaultlook.ui" line="1754"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Amosar as lapelas de todas asáreas de traballo no panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1239"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Mostrar botóns de acción do diálogo de ficheiros GTK na parte inferior dos diálogos</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1246"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation>( tamén desactiva as Decoracións do Lado do Cliente para as aplicacións de Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1259"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1271"/>
        <location filename="../defaultlook.ui" line="1611"/>
        <source>On</source>
        <translation>Amosar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1276"/>
        <location filename="../defaultlook.ui" line="1616"/>
        <source>Off</source>
        <translation>Agochar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1297"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1304"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Configuracións da barra de ferramentas&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1344"/>
        <source>Toggle icon captions</source>
        <translation>Alterna os subtítulos das iconas</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1351"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Restablecer o menú do Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1368"/>
        <source>Width</source>
        <translation>Largura</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1382"/>
        <source>Toggle desktop icons</source>
        <translation>Activa ou desactiva as iconas do escritorio</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1389"/>
        <location filename="../defaultlook.ui" line="1413"/>
        <source>Autohide</source>
        <translation>Agochar automático</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1396"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Configuración do Dock&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1487"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Iconas do escritorio&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1561"/>
        <source>Reset DefaultDock</source>
        <translation>Restablecer a dock predeterminada</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1575"/>
        <source>Manage Tint2 Panel</source>
        <translation>Xestionar o panel Tint2</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1586"/>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1593"/>
        <location filename="../defaultlook.ui" line="1629"/>
        <location filename="../defaultlook.ui" line="1761"/>
        <source>Placement</source>
        <translation>Posicionamento</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1600"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Screensaver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>screensaver screen blank settings</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Protector de pantalla&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1621"/>
        <source>On Hover</source>
        <translation>Ao apuntar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1643"/>
        <location filename="../defaultlook.ui" line="1721"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Restablecer as predeterminas&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1650"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Engade novos elementos do menú predeterminados, se os hai, ao menú de fluxbox existente.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1653"/>
        <source>Upgrade existing menu entries</source>
        <translation>Actualizar entradas de menú existentes</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1673"/>
        <source>Show Toolbar</source>
        <translation>Mostrar a barra de ferramentas</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1690"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Restablecer todas as configuracións do mx-fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1697"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation>Tempo de inactividade (minutos)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1710"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1768"/>
        <source>Enable single-click</source>
        <translation>Acivar premer único</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1775"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Restablcer as predeterminadas do KDE/Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1826"/>
        <source>Workspace</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1850"/>
        <source>Autostart plasma-discover system tray update notification utility</source>
        <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
        <translation>Inicio automático de notificación de actualización da bandexa do sistema plasma-discover</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1860"/>
        <source>Super Key</source>
        <extracomment>referring to the meta or Left Super Key</extracomment>
        <translation>Tecla Super</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1868"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Choose application&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>description of button action to launch file dialog to choose an application</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Escolle a aplicación&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1881"/>
        <source>Xfce-superkey defaults</source>
        <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
        <translation>Predeterminados do Xfce-superkey </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1888"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Also known as the &amp;quot;windows&amp;quot; key&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Tamén coñecida como a tecla &amp;quot;windows&amp;quot;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1891"/>
        <source>Command to run with Super (Meta) key</source>
        <extracomment>label for the field to enter the command to use with super key</extracomment>
        <translation>Comando para executar coa tecla Super (Meta)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1921"/>
        <source>Other</source>
        <translation>Outro</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1929"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requirirá reiniciar&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1932"/>
        <source>Enable Bluetooth adapters on boot</source>
        <translation>Habilitar adaptadores Bluetooth ao arrancar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1939"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Usar o controlador Intel en vez do controlador &quot;modesetting&quot; predeterminado (require reiniciar)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1946"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>          NOTA: o ficheiro /etc/X11/xorg.conf.d/20-radeon.conf existente será gardado no cartafol persoal</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1953"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Restablecer o tema predeterminado da pantalla da entrada (LightDM)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1960"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1970"/>
        <source>Change computer name (requires reboot)</source>
        <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
        <translation>Cambiar o nome do ordenador (require reiniciar)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1977"/>
        <source>Enable kernel sandbox</source>
        <translation>Activar ambiente illado para o núcleo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1984"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Activar o conexión de discos internos por usuarios alén do root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1991"/>
        <source>Enable Bluetooth battery info for connected devices (requires system restart)</source>
        <extracomment>expose battery info for connected bluetooth devices to the operating system via dbus</extracomment>
        <translation>Activar a información da batería de Bluetooth para os dispositivos conectados (require o reinicio do sistema)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1998"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt instala paquetes &quot;recomendados&quot; adicionales como dependencias</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2015"/>
        <source>Password for administrative tasks:</source>
        <translation>Contrasinal para tarefas administrativas:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2022"/>
        <source>put a hold or remove a hold on updates of Liquorix kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>poñer unha retención ou eliminar unha retención nas actualizacións dos Kernels de Liquorix</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2025"/>
        <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Habilitar Actualizacións Automáticas do Kernel Liquorix (repositorio MX ahs)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2032"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>          NOTA: o ficheiro /etc/X11/xorg.conf.d/20-amd.conf existente será gardado no cartafol persoal</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2056"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Usar a opción anti-distorsión do controlador radeon</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2063"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Usar a opción anti-distorsión do controlador amdgpu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2070"/>
        <source>Change Default Display Manager (login screen) (requires reboot)</source>
        <extracomment>option to change display manager login screen.  present if more than one display manager is installed</extracomment>
        <translation>Cambiar o Xestor de Visualización predeterminado (pantalla de inicio de sesión) (require reinicio)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2077"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Usa as decoracións do lado do cliente (CSD) en aplicativos GTK3 que as admitan (require reinicio da sesión)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2084"/>
        <source>&amp;User</source>
        <translation>&amp;Usuari</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2091"/>
        <source>put a hold or remove a hold on updates of Debian  kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>poñer unha retención ou eliminar unha retención nas actualizacións dos kernels de Debian</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2094"/>
        <source>Enable Automatic Debian Kernel Updates</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Habilitar actualizacións automáticas do kernel Debian</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2114"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>          NOTA: o ficheiro /etc/X11/xorg.conf.d/20-intel.conf existente será gardado no cartafol persoal</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2121"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation>Xerar menú Todas as Aplicacións de fluxbox despois da instalación, eliminación e actualización de paquetes.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2128"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Early loading of KVM module is new to  kernel 6.12 and conflicts with some non-KVM virtual machine applications, including virtualbox &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>early loading is new on 6.12 kernel and conflicts with virtualbox</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt; A carga anticipada do módulo KVM é nova para o núcleo 6.12 e entra en conflito con algunhas aplicacións de máquinas virtuais non KVM, incluído o Virtualbox&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2131"/>
        <source>Disable early KVM module load (must be disabled for Virtualbox operation on kernel 6.12 and up)</source>
        <extracomment>disable early loading of KVM module.  necessary for virtualbox to function with kernels 6.12 and up.  actually default behavior on kernels 6.11 and earlier.</extracomment>
        <translation>Desactivar a carga inicial do módulo KVM (debe estar desactivado para o funcionamento de Virtualbox no kernel 6.12 ou superior)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="61"/>
        <source>--display switch only valid for Xfce</source>
        <translation>-cambio na pantalla válido só para o Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="671"/>
        <source>About MX Tweak</source>
        <translation>Sobre MX Axustes Rápidos</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="673"/>
        <source>Version: </source>
        <translation>Versión</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="674"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Aplicativo para rapidamente facer cambios ao tema predeterminado da interface de usuario e outros axustes</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="676"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="677"/>
        <source>%1 License</source>
        <translation>Licenza de %1</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="691"/>
        <source>%1 Help</source>
        <translation>Axuda para %1</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="701"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Feito! Firefox pode ter que ser reiniciado para os cambios teren efecto</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="748"/>
        <source>Plese remove special characters</source>
        <translation>Por favor, elimina os caracteres especiais</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="748"/>
        <source>from file name</source>
        <translation>do nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="755"/>
        <source>File name already exists.  Choose another name</source>
        <translation>O nome do ficheiro xa existe. Escolle outro nome</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="783"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>O ficheiro non é un ficheiro de arquivo tar.xz válido</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="786"/>
        <source>Archive does not contain a panel config</source>
        <translation>O arquivo non contén unha configuración de panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="961"/>
        <source>Panel settings</source>
        <translation>Coniguración do panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="962"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>As actuais ocnfiguracións do panel foron gardados nun cartafol oculto chamado .restore no cartafol persoal (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1662"/>
        <source>Plasma Widget Themes</source>
        <comment>theme style of the kde plasma widgets</comment>
        <translation>Temas de widgets de plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1663"/>
        <source>Color Schemes</source>
        <comment>plasma widget color schemes</comment>
        <translation>Esquemas de cores</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1664"/>
        <source>Plasma Look &amp; Feel Global Themes</source>
        <comment>plasma global themes</comment>
        <translation>Temas globais de aspecto e sensación de plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1932"/>
        <source>settings</source>
        <translation>configuración</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2273"/>
        <source>Choose a theme set</source>
        <translation>Elixe un tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2737"/>
        <source>Please enter a computer name.</source>
        <comment>question to enter a name for the computer hostname</comment>
        <translation>Inserir un nome do computador.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2741"/>
        <source>Sorry, your computer name contains invalid characters.
You&apos;ll have to select a different
name before proceeding.</source>
        <comment>unacceptable characters are found in hostname, pick a new name</comment>
        <translation>O nome do computador contén caracteres inválidos. Ten que ser escollido un nome diferente antes de proseguir.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="4374"/>
        <source>Select application to run</source>
        <comment>will show in file dialog when selection an application to run</comment>
        <translation>Selecciona a aplicación para executar</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Eliminar tema do usuario</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Novo tema establecido</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Inserir o nome do tema novo establecido</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Botóns de lapela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Apariencia&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Amosar rótulos dos botóns</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Amosar botóns sen relevo</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Amosar o manexo</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Ordenación:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Estampa de data/hora</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Título do grupo e estampa de data/hora</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Título da lapela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Título do grupo e título da lapela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Ningún; permitir arrastrar-e-deixar caer</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Comportamento&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Agrupamento de lapelas:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Acción do botón central:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Sen acción</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Pechar lapela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Minimizar lapela</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Restaurar as lapelas minimizadas no escritorio actual</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Deseñar caixiña da lapela ao pasar sobre un botón</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Cambiar de lapela coa roda do rato</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtrar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>AMosar lapelas de todas as áreas de traballo ou lapelas embebidas</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Amosar só lapelas minimizadas</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Amosar lapelas de todos os monitores</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Caixa de diálogo</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Lapelas emerxentes</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Ao mover </translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Configuración de opacidade&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Moldura da lapela</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Amosar sombreado nas lapelas en doca</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Amosar sombreado nas lapelas emerxentes</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Ao redimensionar</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Amosar sombreado nas lapelas normais</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Configuración das funcionalidades&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Ao percorrer as lapelas amosar a previsualización en vez das iconas</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Exhibir directamente as lapelas de sobreposición da pantalla interna</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Lapelas inactivas</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Sincronizar o deseño co trazo en branco vertical</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Configuración do compositor do Xfwm</translation>
    </message>
</context>
</TS>
